PSVG Publication Repository
===========================

This repository contains the group's (and its members') publications, BibTeX
references, and associated materials.

## How to Deposit a Publication.
1. To fulfill funding and REF requirements and for long-term archival, all
   papers and tech reports should be deposited into
   [Imperial Spiral](http://spiral.imperial.ac.uk/) using [Symplectic](https://www.imperial.ac.uk/SymplecticElements/)
   within THREE MONTHS OF ACCEPTANCE. Do this now, so you don't forget.

2. Email Teresa with a copy of the accepted submission so that she can publish
   the details of the acceptance in the news section of the website.

2. Create a BibTeX record for the publication in
   the [publications.bib](publications.bib) file. Post-publication, records can
   be retrieved from [DBLP](http://dblp.org/),
   [ACM Digital Library](http://dl.acm.org/), and the publisher's website. It
   may be best to download the citations from all sites and pick the most
   appropriate version of each field, as they all usually vary in quality.
   See below for BibTeX style notes.

3. Commit files associated with the publication to this directory. *Files
   should be named with the bibtex key as the root of the file name*, and the
   appropriate extension from the section below according to document purpose.

## Copyright Notes
** Please take careful note of this section!**

You **must** check with the publisher's T&Cs (in particular the Copyright
waiver form) to determine which version of the paper you are allowed to publish
here. Often it is only the *pre-print* edition that is passed to the publisher
*before* they make any changes. The final proof copy and the publisher's own
copy is usually not permitted to be published on the author's own website.

## BibTeX
A BibTeX record looks like this:
```bibtex
@Type{Key,
  field = {value},
  field = {value},
}
```

For details of the possible types of entries, and their minimal set of required
fields, see [the Wikipedia BibTeX article](https://en.wikipedia.org/wiki/BibTeX#Entry_types).

For the group websites, we've chosen a BibTeX key format of:
`<first author surname><year><first word of title>`, this is used as the
record's key in the `publications.bib` file, and as the root of the filename
for each associated file (article, slides, etc) in this repository.

In values, Surround special characters and characters requiring exact
capitalisation in `{}` curly braces. For example:
`Naud{\v{z}}i{\={u}}nien{\.{e}}` and `{ECMAS}cript`.

### Fields Style Guide
* **author**: Author names should be separated by `and`, names can be in either
  the `Last, First` *(preferred)* or `First Last` style.
  Multiple-word last names should use the `Last, First` style to minimise
  confusion. For example: `da Rocha Pinto, Pedro and Fragoso Santos, Jos{\'e}
  and D'Osualdo, Emanuele`. For further details of how BibTeX treats names, see
  [this summary](http://artis.imag.fr/~Xavier.Decoret/resources/xdkbibtex/bibtex_summary.html#names).
* **doi**: Please remove the `http://dx.doi.org/` prefix, so the DOI, so it is
  of the form `nn.nnnn/xyzabc`. For display on the website, this value will be
  prefixed with `http://dx.doi.org/` to produce a link to the publisher's
  article website.
* **url**: This field should **not** contain a duplicate of the doi. It is
  generally only used to link to the publisher's version if the publisher does
  not also issue a DOI. If the publisher's link is the same location as the DOI
  after redirections, then it should not be filled in the url field.
* **month**: **Required** The first three letters of the month of publication (possibly in
  the future). This field does not require quoting or placing into braces.
  The standard months are: jan, feb, mar, apr, may, jun, jul, aug, sep, oct,
  nov, dec. For example: `month = mar,`.
  Publications will not appear on the websites until their month of
  publication (as per Philippa's policy decision).
* **year**: **Required** Year of publication.
* **file**: This field is added automatically by the JabRef reference manager,
  it is ignored by the website. It is mostly useful as a quick check in the
  JabRef user interface that all publications have an associated file. See next
  section for file matching on the website.
* **booktitle**: For the `@inproceedings` type, this is the title of the
  conference proceedings. Different publishers prefer different (long) styles,
  Philippa usually prefers something short like POPL'12. We may need to find a
  way to standardise on this.

### Further Reading/References
* [Wikipedia BibTeX article](https://en.wikipedia.org/wiki/BibTeX)
* The [BibTeX FAQ](http://mirrors.ctan.org/biblio/bibtex/contrib/doc/btxFAQ.pdf)
* [Xavier Decoret's guide](http://artis.imag.fr/~Xavier.Decoret/resources/xdkbibtex/bibtex_summary.html)
* [Tame the BeaST](http://www.lsv.fr/~markey/BibTeX/doc/ttb_en.pdf), by Nicolas
  Markey

## Publication File Extension Types
Publication file types are listed in the configuration file
[`_publication_file_types.yml`](_publication_file_types.yml). These file types will
be offered directly for download:
* `.pdf`: Authors' Preprint / Accepted Version
* `.published.pdf`: Published Version (_Note: only upload this if redistribution permitted by publisher._)
* `.abstract.pdf`: Extended Abstract
* `.extended.pdf`: Extended Version
* `.techreport.pdf`: Technical Report
* `.slides.pdf`: Slides
* `.zip`: File Archive (.zip)
* `.tgz`: File Archive (.tgz)

These extensions are for plain text files containing _only_ the URL to link to:
* `.github.link`: Code Repository (GitHub)
* `.repo.link`: Code Repository

## Converting Old .ps Files
If you come across and old `.ps` or `.ps.gz` file, it should be converted to a
PDF. This can be tricky to do in a way that preserves the font information
adequately. These instructions should cover all eventualities:

1. Check what software produced the file `grep Creator file.ps`, if the
   software listed is `dvips`, then follow the instructions
   [here](https://tex.stackexchange.com/a/120273/15188).
2. Otherwise, you can use the `ps2pdf` software. If the original document page
   size is A4, then you should add the parameter `-sPAPERSIZE=a4` to your
   command.

## Git Submodule Notes
This repository is included as a submodule in the repositories for the [Group
Website](https://gitlab.doc.ic.ac.uk/resource-reasoning/psvg.doc.ic.ac.uk) and
[Philippa's Homepage](https://gitlab.doc.ic.ac.uk/resource-reasoning/pgwebpage).

Be aware that changes to the publications directory **must** be committed **and
pushed** to the submodule (and optionally, to the top-level project).

Website builds will always take the `master` branch of the publications
repository, no matter what submodule version is committed to the website
repositories, as they use the command `git submodule update --remote`, which
always fetches the most recent version for use.

This repository can be included in website repositories either as a submodule or
as a checkout before build/deploy. Post-checkin/test pass hooks can be
configured on this repository to retrigger a website submodule update/rebuild as
desired.

